Crate konfik_derive

Crate konfik_derive 

konfik_derive

Procedural macro derive for the konfik configuration parsing library.

This crate provides the #[derive(Config)] macro that automatically implements the necessary traits for structs to work seamlessly with the konfik configuration loader.

Derive Macros

Konfik
Konfik
Nested
Nested